import json, os


def leet(text):
    current_dir = os.path.dirname(__file__)

    leet_dict_path = os.path.join(current_dir, "assets", "leet_dict.json")

    with open(leet_dict_path, "r") as file:
        leet_dict = json.load(file)

    leet_text = "".join(leet_dict.get(char, char) for char in text)

    return leet_text



import random as r


def cartijoin(input_arr):
    separators = [r.choice([" ", "  ", "   ", "-"]) for _ in range(len(input_arr))]

    result = ""
    for i, item in enumerate(input_arr):
        result += item
        if i < len(separators):
            result += separators[i]

    return result



import json, os, random as r

from cartinize.leet import leet
from cartinize.cartijoin import cartijoin


def cartinize(string):
    current_dir = os.path.dirname(__file__)

    carti_fillers_path = os.path.join(current_dir, "assets", "cart_fillers.json")

    with open(carti_fillers_path, "r") as file:
        carti_fillers = json.load(file)

    def randomize_symbol(char):
        return r.choice([str.upper, str.lower, leet])(char)

    input_list = string.split(" ")

    result = []
    for i in input_list:
        word = "".join(list(map(randomize_symbol, list(i))))
        result.append(word)
        result.append(r.choice(carti_fillers))

    return cartijoin(result)



from setuptools import setup, find_packages

VERSION = '0.1.4'
DESCRIPTION = 'Cartinese translator'

setup(
    name="cartinize",
    version=VERSION,
    author="ktkv419 (Kutikov Pasha)",
    author_email="<kutikovpasha@gmail.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=['python', 'string', 'translate', 'carti', 'slatt'],
)
